flutter_heyteacher_platform library

Classes

ContextHelper
Context helper for get BuildContext outside widget, for example getting localization in business logic.
DevicePackageInfoCard
A widget that displays device and package information in a list tile format.
FlutterHeyteacherPlatformLocalizations
Callers can lookup localized strings with an instance of FlutterHeyteacherPlatformLocalizations returned by FlutterHeyteacherPlatformLocalizations.of(context).
InfoDevicePackageViewModel
A singleton model class responsible for fetching and providing device-specific information and application package details.
PlatformHelper
A utility class offering static boolean flags to identify the current platform.