PlatformHelper class final

A utility class offering static boolean flags to identify the current platform.

This class cannot be instantiated and all its members are static.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

isAndroid bool
true if the application is running on Android.
final
isFlutterTest bool
true if the application is running in a test environment.
no setter
isIOS bool
true if the application is running on iOS.
final
isMobile bool
true if the application is running on a mobile platform (Android or iOS).
final
isNotMobile bool
true if the application is running in a web browser, linux or windows. but not on mobile.
final
isNotWeb bool
true if the application is not running in a web browser.
no setter

Constants

isWeb → const bool
true if the application is running in a web browser, linux or windows.