PlatformHelper class final
A utility class offering static boolean flags to identify the current platform.
This class cannot be instantiated and all its members are static.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- isAndroid → bool
-
trueif the application is running on Android.final - isFlutterTest → bool
-
trueif the application is running in a test environment.no setter - isIOS → bool
-
trueif the application is running on iOS.final - isMobile → bool
-
trueif the application is running on a mobile platform (Android or iOS).final - isNotMobile → bool
-
trueif the application is running in a web browser, linux or windows. but not on mobile.final - isNotWeb → bool
-
trueif the application is not running in a web browser.no setter